package net.wanji.opt.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.annotation.aspect.AspectLog;
import net.wanji.common.enums.BaseEnum;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.bo.BottomCurveBO;
import net.wanji.opt.bo.BottomMenuBO;
import net.wanji.opt.bo.MainlineSchemeAnalysisBO;
import net.wanji.opt.service.impl.MainlineEvaluateServiceImpl;
import net.wanji.opt.vo.MainlineEvaluateBottomCurveVO;
import net.wanji.opt.vo.MainlineSchemeAnalysisVO;
import org.springframework.web.bind.annotation.*;

import javax.ws.rs.core.MediaType;
import java.text.ParseException;
import java.util.List;
import java.util.Set;

@Api(value = "MainlineEvaluateController", description = "干线评价")
@RequestMapping("/mainlineEvaluate")
@RestController
public class MainlineEvaluateController {

    private final MainlineEvaluateServiceImpl mainlineEvaluateService;

    public MainlineEvaluateController(MainlineEvaluateServiceImpl mainlineEvaluateService) {
        this.mainlineEvaluateService = mainlineEvaluateService;
    }

    @ApiOperation(value = "底部曲线图范围下拉列表", notes = "底部曲线图范围下拉列表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/bottomMenu",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = JsonViewObject.class),
    })
    public JsonViewObject bottomMenu(@RequestBody BottomMenuBO bo) {
        List<String> res = mainlineEvaluateService.bottomMenu(bo);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "底部曲线图", notes = "底部曲线图", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/bottomCurve",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = MainlineEvaluateBottomCurveVO.class),
    })
    public JsonViewObject bottomCurve(@RequestBody BottomCurveBO bo) throws ParseException {
        List<MainlineEvaluateBottomCurveVO> res = mainlineEvaluateService.bottomCurve(bo);
        return JsonViewObject.newInstance().success(res);
    }

    @AspectLog(description = "干线列表", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @ApiOperation(value = "干线列表", notes = "干线列表")
    @GetMapping("/mainlineList")
    public JsonViewObject mainlineList() {
        Set<String> res = mainlineEvaluateService.mainlineList();
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "干线方案分析", notes = "干线方案分析", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/mainlineSchemeAnalysis",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = MainlineSchemeAnalysisVO.class),
    })
    public JsonViewObject mainlineSchemeAnalysis(@RequestBody MainlineSchemeAnalysisBO bo) {
        MainlineSchemeAnalysisVO res = mainlineEvaluateService.mainlineSchemeAnalysis(bo);
        return JsonViewObject.newInstance().success(res);
    }
}